@@ -1,10 +1,10 @@
 # $File: //depot/OurNet-BBS/BBS/MAPLE3/UserGroup.pm $ $Author: autrijus $
-# $Revision: #14 $ $Change: 1630 $ $DateTime: 2001/08/31 04:14:01 $
+# $Revision: #17 $ $Change: 2440 $ $DateTime: 2001/11/27 15:38:54 $
 
 package OurNet::BBS::MAPLE3::UserGroup;
 
 use strict;
-use fields qw/bbsroot shmkey maxuser _ego _hash _array/;
+use fields qw/bbsroot _ego _hash _array/;
 use subs qw/writeok readok/;
 use OurNet::BBS::Base;
 
@@ -12,7 +12,6 @@ use constant IsWin32 => ($^O eq 'MSWin32');
 use open (IsWin32 ? (IN => ':raw', OUT => ':raw') : ());
 
 sub writeok { 0 }
-
 sub readok { 1 }
 
 sub FETCHSIZE {
@@ -38,7 +37,7 @@ sub refresh_meta {
         else {
             # key fetch
             $name = $key;
-            $key = 0;
+	   undef $key
         }
 
 	return if $self->{_hash}{$name};
@@ -50,7 +49,7 @@ sub refresh_meta {
         $key,
     );
 
-    $key ||= $obj->{userno};
+    $key = $obj->{userno} - 1 unless defined $key;
 
     $self->{_hash}{$name} = $self->{_array}[$key] = $obj;
 
