@@ -1,5 +1,5 @@
 # $File: //depot/OurNet-BBS/BBS/MELIX/SessionGroup.pm $ $Author: autrijus $
-# $Revision: #11 $ $Change: 2053 $ $DateTime: 2001/10/13 23:46:19 $
+# $Revision: #14 $ $Change: 2456 $ $DateTime: 2001/11/28 12:16:45 $
 
 package OurNet::BBS::MELIX::SessionGroup;
 
@@ -7,6 +7,7 @@ use strict;
 use base qw/OurNet::BBS::MAPLE3::SessionGroup/;
 use fields qw/lastref _ego _hash/;
 use subs qw/refresh_meta shminit STORE message_handler DESTROY/;
+use constant IsWin32 => ($^O eq 'MSWin32');
 
 use OurNet::BBS::Base (
      '$packstring'	=> 'LLLLLLLLa18Z13Z13Z24Z34x2',
@@ -25,6 +26,8 @@ sub refresh_meta {
     $self->shminit unless ($self->{shmid} || !$self->{shmkey});
 
     if ($key eq int($key)) {
+	no strict 'vars';
+
         print "new toy called $key\n" 
 	    if !$self->{_hash}{$key} and $OurNet::BBS::DEBUG;
 
@@ -44,27 +47,31 @@ sub refresh_meta {
 sub shminit {
     my $self = shift;
 
-    if ($^O ne 'MSWin32' and
-	$self->{shmid} = shmget($self->{shmkey},
-				($self->{maxsession})*$packsize+36, 0)) {
-      tie $self->{shm}{number}, 'OurNet::BBS::ShmScalar',
-	  $self->{shmid}, $self->{maxsession} * $packsize     , 4, 'L';
-      tie $self->{shm}{offset}, 'OurNet::BBS::ShmScalar',
-	  $self->{shmid}, $self->{maxsession} * $packsize +  4, 4, 'L';
-      tie @{$self->{shm}{sysload}}, 'OurNet::BBS::ShmArray',
-	  $self->{shmid}, $self->{maxsession} * $packsize +  8, 8, 3, 'd';
-      tie $self->{shm}{avgload}, 'OurNet::BBS::ShmScalar',
-	  $self->{shmid}, $self->{maxsession} * $packsize + 32, 4, 'L';
-      tie $self->{shm}{mbase}, 'OurNet::BBS::ShmScalar',
-	  $self->{shmid}, $self->{maxsession} * $packsize + 36, 4, 'L';
-      tie @{$self->{shm}{mpool}}, 'OurNet::BBS::ShmArray',
-	  $self->{shmid}, $self->{maxsession} * $packsize + 40, 100, 128, 'LLLLZ13Z71';
+    if ($^O ne 'MSWin32' and $self->{shmid} = shmget(
+	$self->{shmkey}, ($self->{maxsession}) * $packsize + 36, 0)
+    ) {
+	tie $self->{shm}{number}, 'OurNet::BBS::ShmScalar',
+	    $self->{shmid}, $self->{maxsession} * $packsize     , 4, 'L';
+	tie $self->{shm}{offset}, 'OurNet::BBS::ShmScalar',
+	    $self->{shmid}, $self->{maxsession} * $packsize +  4, 4, 'L';
+	tie @{$self->{shm}{sysload}}, 'OurNet::BBS::ShmArray',
+	    $self->{shmid}, $self->{maxsession} * $packsize +  8, 8, 3, 'd';
+	tie $self->{shm}{avgload}, 'OurNet::BBS::ShmScalar',
+	    $self->{shmid}, $self->{maxsession} * $packsize + 32, 4, 'L';
+	tie $self->{shm}{mbase}, 'OurNet::BBS::ShmScalar',
+	    $self->{shmid}, $self->{maxsession} * $packsize + 36, 4, 'L';
+	tie @{$self->{shm}{mpool}}, 'OurNet::BBS::ShmArray',
+	    $self->{shmid}, $self->{maxsession} * $packsize + 40, 100, 128,
+		'LLLLZ13Z71';
 
-      $instances{$self} = $self;
+	no strict 'vars';
+	$instances{$self} = $self;
     }
 }
 
 sub message_handler {
+    no strict 'vars';
+
     # we don't handle multiple messages in the queue yet.
 
     foreach my $instance (values %instances) {
@@ -94,10 +101,10 @@ sub message_handler {
         }
     }
 
-    $SIG{USR2} = \&message_handler;
+    $SIG{USR2} = \&message_handler unless IsWin32;
 };
 
-$SIG{USR2} = \&message_handler;
+$SIG{USR2} = \&message_handler unless IsWin32;
 
 sub STORE {
     my ($self, $key, $value) = @_;
@@ -140,6 +147,8 @@ sub lastref { shift->ego->{lastref} }
 sub DESTROY {
     my $self = shift->ego;
 
+    no strict 'vars';
+
     delete $instances{$self};
 }
 
