@@ -1,36 +1,28 @@
 # $File: //depot/OurNet-BBS/BBS/MailBox/Article.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 1439 $ $DateTime: 2001/07/15 14:19:48 $
+# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
 
 package OurNet::BBS::MailBox::Article;
 
 use strict;
-use base qw/OurNet::BBS::Base/;
-use fields qw/mgr board folder name recno _cache/;
-
-BEGIN {
-    __PACKAGE__->initvars(
-        'ArticleGroup' => [qw/@packlist/],
-    );
-}
-
-sub new_id { }
+use fields qw/mgr board folder name recno _ego _hash/;
+use OurNet::BBS::Base;
 
 sub refresh_body {
     my $self = shift;
-    return if $self->{_cache}{body};
+    return if defined $self->{_hash}{body};
 
-    $self->{_cache}{body} = join(
+    $self->{_hash}{body} = join(
 	'', @{$self->{folder}->message($self->{recno})->body}
     );
 }
 
 sub refresh_header { 
     my $self = shift;
-    return if $self->{_cache}{header};
+    return if $self->{_hash}{header};
 
     my $head = $self->{folder}->message($self->{recno})->head;
 
-    $self->{_cache}{header} = { 
+    $self->{_hash}{header} = { 
 	map { $_ => substr(join('', $head->get($_)), 0, -1) } 
 	map { $_ eq 'Message-Id' ? 'Message-ID' : $_ } 
 	keys %{$head->{mail_hdr_hash}} 
@@ -42,9 +34,9 @@ sub refresh_meta {
 
     $self->refresh_header;
 
-    $self->{_cache}{author} = $self->{_cache}{header}{From};
-    $self->{_cache}{title}  = $self->{_cache}{header}{Subject};
-    $self->{_cache}{board}  = $self->{_cache}{header}{Board} = $self->{board};
+    $self->{_hash}{author} = $self->{_hash}{header}{From};
+    $self->{_hash}{title}  = $self->{_hash}{header}{Subject};
+    $self->{_hash}{board}  = $self->{_hash}{header}{Board} = $self->{board};
 
     1;
 }
