@@ -1,5 +1,5 @@
 # $File: //depot/OurNet-BBS/BBS/Server.pm $ $Author: autrijus $
-# $Revision: #50 $ $Change: 2064 $ $DateTime: 2001/10/15 07:20:27 $
+# $Revision: #54 $ $Change: 2454 $ $DateTime: 2001/11/28 07:08:31 $
 
 package OurNet::BBS::Server;
 
@@ -113,20 +113,25 @@ sub daemonize {
 
     if ($AuthLevel & (AUTH_CRYPT | AUTH_PGP)) {
 	if (UNIVERSAL::isa($ROOT, 'OurNet::BBS')) {
-	    local $@;
 	    no warnings;
 
-	    my $sysop = eval { $ROOT->{users}{SYSOP} } || [];
+	    my $users = eval { $ROOT->{users} };
+	    my $sysop = eval { $users->{SYSOP} } || [];
+	    my $guest = eval { $users->{guest} } || [];
+
+	    local $@;
 
 	    $AuthLevel &= ~AUTH_CRYPT unless eval{
 		$sysop->{passwd} 
-	    } and !$@;
-
-	    undef $@;
+	    } or eval {
+		$guest->{passwd} 
+	    };
 
 	    $AuthLevel &= ~AUTH_PGP unless eval{
-		$sysop->{plans} 
-	    } or !$@;
+		$sysop->{plans}
+	    } or eval {
+		$guest->{plans}
+	    };
 	}
 	else {
 	    $AuthLevel &= ~(AUTH_CRYPT | AUTH_PGP)
@@ -163,6 +168,9 @@ sub handshake {
     nextstate('get_suites', 'get_pubkey', 'cipher_none');
     $Server->{methods}{__}{handshake} = 1; # allows re-authenticate
 
+    $CipherLevel &= ~CIPHER_PGP and $AuthLevel &= ~AUTH_PGP
+	unless $Auth and $Auth->test;
+
     return ($CipherLevel & $cipher_level, $AuthLevel & $auth_level);
 }
 
